
%if 0%{?fedora}
# The Kalzium solver needs OCaml with native compilation support (ocamlopt) and
# ocaml-facile.
%ifarch %{arm} %{ix86} x86_64 ppc ppc64 sparc sparcv9
%global with_facile 1
%endif
%if 0%{?fedora} > 20
%ifarch aarch64
%global with_facile 1
%endif
%endif
%endif

%if 0%{?fedora} > 20
# Avogadro has ExcludeArch ARM on F21+
%ifnarch %{arm}
%global with_avogadro 1
%endif
%else
%global with_avogadro 1
BuildRequires: pkgconfig(eigen2)
%endif

Name:    kalzium
Summary: Periodic Table of Elements
Version: 4.14.1
Release: 1%{?dist}

License: GPLv2+
URL:     https://projects.kde.org/projects/kde/kdeedu/%{name}
%global revision %(echo %{version} | cut -d. -f3)
%if %{revision} >= 50
%global stable unstable
%else
%global stable stable
%endif
Source0: http://download.kde.org/%{stable}/%{version}/src/%{name}-%{version}.tar.xz

%if 0%{?fedora} > 19
BuildRequires: appdata-tools
%endif
BuildRequires: chemical-mime-data
BuildRequires: desktop-file-utils
BuildRequires: kdelibs4-devel >= %{version}
BuildRequires: libkdeedu-devel >= %{version}
# build.log says that OpenBabel is for the "3D-molecule viewer", but it is also
# used in other optional components than the Avogadro-based compound viewer.
BuildRequires: pkgconfig(openbabel-2.0)
BuildRequires: python-devel python
%if 0%{?with_avogadro}
# Eigen is only used for the Avogadro-based compound viewer.
BuildRequires: pkgconfig(eigen3)
BuildRequires: avogadro-devel
%endif
%if 0%{?with_facile}
# OCaml is only used with the Facile library, in the equation balancer.
BuildRequires: ocaml(compiler)
BuildRequires: ocaml-facile-devel
%endif

Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: kde-runtime%{?_kde4_version: >= %{_kde4_version}}
# build.log wants this one, but it is really only used at runtime:
Requires: chemical-mime-data

%description
%{summary}.

%package  libs
Summary:  Runtime files for %{name}
Requires: %{name} = %{version}-%{release}
Requires: libkdeedu%{?_isa} >= %{version}
%description libs
%{summary}.

%package devel
Summary:  Development files for %{name}
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: libkdeedu-devel 
%description devel
%{summary}.


%prep
%setup -q


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake_kde4} ..
popd

make %{?_smp_mflags} -C %{_target_platform}


%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

%find_lang %{name} --with-kde --without-mo


%check
appdata-validate --nonet --relax %{buildroot}%{_kde4_datadir}/appdata/%{name}.appdata.xml ||:
desktop-file-validate %{buildroot}%{_kde4_datadir}/applications/kde4/kalzium.desktop
desktop-file-validate %{buildroot}%{_kde4_datadir}/applications/kde4/kalzium_cml.desktop


%post
touch --no-create %{_kde4_iconsdir}/hicolor &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null || :
update-desktop-database -q &> /dev/null ||:

%postun
if [ $1 -eq 0 ] ; then
touch --no-create %{_kde4_iconsdir}/hicolor &> /dev/null || :
gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null || :
update-desktop-database -q &> /dev/null ||:
fi

%files -f %{name}.lang
%doc COPYING
%{_kde4_bindir}/kalzium
%{_kde4_appsdir}/kalzium/
%{_kde4_datadir}/kde4/services/plasma-dataengine-kalzium.desktop
%{_kde4_libdir}/kde4/concentrationCalculator.so
%{_kde4_libdir}/kde4/gasCalculator.so
%{_kde4_libdir}/kde4/nuclearCalculator.so
%{_kde4_libdir}/kde4/plasma_applet_didyouknow.so
%{_kde4_libdir}/kde4/plasma_applet_molmassCalculator.so
%{_kde4_libdir}/kde4/plasma_engine_kalzium.so
%{_kde4_datadir}/appdata/%{name}.appdata.xml
%{_kde4_datadir}/applications/kde4/kalzium.desktop
%{_kde4_datadir}/applications/kde4/kalzium_cml.desktop
%{_kde4_datadir}/config.kcfg/kalzium.kcfg
%{_kde4_configdir}/kalzium.knsrc
%{_kde4_iconsdir}/hicolor/*/*/kalzium.*
%{_mandir}/man1/kalzium.*
%{_kde4_appsdir}/desktoptheme/default/widgets/chalkboard.svg
%{_kde4_appsdir}/libkdeedu/data/
%{_kde4_datadir}/kde4/services/concentrationCalculator.desktop
%{_kde4_datadir}/kde4/services/gasCalculator.desktop
%{_kde4_datadir}/kde4/services/nuclearCalculator.desktop
%{_kde4_datadir}/kde4/services/plasma-applet-Molmasscalculator.desktop
%{_kde4_datadir}/kde4/services/plasma_didyouknow.desktop

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%files libs
%if 0%{?with_avogadro}
%{_kde4_libdir}/libcompoundviewer.so.4*
%endif
%{_kde4_libdir}/libscience.so.4*

%files devel
%{_kde4_includedir}/libkdeedu/*.h
%if 0%{?with_avogadro}
%{_kde4_libdir}/libcompoundviewer.so
%endif
%{_kde4_libdir}/libscience.so


%changelog
* Tue Sep 16 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.14.1-1
- 4.14.1

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.14.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Aug 15 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.14.0-1
- 4.14.0

* Tue Aug 05 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.13.97-1
- 4.13.97

* Tue Jul 15 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.13.3-1
- 4.13.3

* Mon Jun 09 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.13.2-1
- 4.13.2

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.13.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 11 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.13.1-1
- 4.13.1

* Sat Apr 12 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.13.0-1
- 4.13.0

* Fri Apr 04 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.97-1
- 4.12.97

* Sun Mar 23 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.95-1
- 4.12.95

* Wed Mar 19 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.90-1
- 4.12.90

* Sun Mar 02 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.3-1
- 4.12.3

* Fri Jan 31 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.2-1
- 4.12.2

* Sat Jan 25 2014 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.12.1-4
- Requires: chemical-mime-data

* Sat Jan 25 2014 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.12.1-3
- Disable avogadro support on ARM on F21+, drop ExcludeArch added in -2
- Enable facile support on aarch64 on F21+

* Sat Jan 25 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.1-2
- rebuild (avogadro)

* Fri Jan 10 2014 Rex Dieter <rdieter@fedoraproject.org> - 4.12.1-1
- 4.12.1

* Thu Dec 19 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.12.0-1
- 4.12.0

* Sun Dec 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.11.97-1
- 4.11.97

* Thu Nov 21 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.11.95-1
- 4.11.95

* Mon Nov 18 2013 Dave Airlie <airlied@redhat.com> - 4.11.90-2
- rebuilt for GLEW 1.10

* Sat Nov 16 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.11.90-1
- 4.11.90

* Sat Nov 02 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.11.3-1
- 4.11.3

* Sat Sep 28 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.11.2-1
- 4.11.2

* Sun Sep 15 2013 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.11.1-2
- Rebuild for OCaml 4.01.0
- Drop Fedora < 18 conditional

* Wed Sep 04 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.11.1-1
- 4.11.1

* Thu Aug 08 2013 Than Ngo <than@redhat.com> - 4.11.0-1
- 4.11.0

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 4.10.97-2
- Rebuild for boost 1.54.0

* Thu Jul 25 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.97-1
- 4.10.97

* Tue Jul 23 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.95-1
- 4.10.95

* Fri Jun 28 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.90-1
- 4.10.90

* Sat Jun 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.4-1
- 4.10.4

* Mon May 06 2013 Than Ngo <than@redhat.com> - 4.10.3-1
- 4.10.3

* Sun Mar 31 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.2-1
- 4.10.2

* Sat Mar 02 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.1-1
- 4.10.1

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.10.0-3
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 4.10.0-2
- Rebuild for Boost-1.53.0

* Fri Feb 01 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.10.0-1
- 4.10.0

* Tue Jan 22 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.9.98-1
- 4.9.98

* Fri Jan 04 2013 Rex Dieter <rdieter@fedoraproject.org> - 4.9.97-1
- 4.9.97

* Thu Dec 20 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.95-1
- 4.9.95

* Thu Dec 13 2012 Adam Jackson <ajax@redhat.com> - 4.9.90-2
- Rebuild for glew 1.9.0

* Tue Dec 04 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.90-1
- 4.9.90

* Mon Dec 03 2012 Than Ngo <than@redhat.com> - 4.9.4-1
- 4.9.4

* Sat Nov 03 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.3-1
- 4.9.3

* Sun Oct 28 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.9.2-2
- rebuild for OCaml 4.00.1

* Sat Sep 29 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.9.2-1
- 4.9.2

* Mon Sep 03 2012 Than Ngo <than@redhat.com> - 4.9.1-1
- 4.9.1 

* Thu Aug 09 2012 Rex Dieter <rdieter@fedoraproject.org> 4.9.0-2
- rebuild (avogadro/boost)

* Thu Jul 26 2012 Lukas Tinkl <ltinkl@redhat.com> - 4.9.0-1
- 4.9.0

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.8.97-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul 12 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.97-1
- 4.8.97

* Wed Jun 27 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.95-1
- 4.8.95

* Sat Jun 09 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.90-1
- 4.8.90
- rebuild for OCaml 4.00.0 and update ocamlopt arch list

* Fri Jun 01 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.80-1
- 4.8.80

* Mon Apr 30 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.3-1
- 4.8.3

* Fri Mar 30 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.2-1
- 4.8.2

* Mon Mar 05 2012 Jaroslav Reznik <jreznik@redhat.com> - 4.8.1-1
- 4.8.1

* Sun Jan 22 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.8.0-1
- 4.8.0

* Sat Jan 07 2012 Kevin Kofler <Kevin@tigcc.ticalc.org> - 4.7.97-2
- Rebuild for new OCaml (3.12.1)
- Enable facile on ARM, ocamlopt available on ARM these days

* Wed Jan 04 2012 Rex Dieter <rdieter@fedoraproject.org> - 4.7.97-1
- 4.7.97

* Thu Dec 22 2011 Radek Novacek <rnovacek@redhat.com> - 4.7.95-1
- 4.7.95

* Sun Dec 04 2011 Rex Dieter <rdieter@fedoraproject.org> - 4.7.90-1
- 4.7.90

* Fri Nov 25 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.80-1
- 4.7.80

* Sat Oct 29 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.3-1
- 4.7.3

* Wed Oct 05 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.2-1
- 4.7.2

* Sat Sep 17 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.1-1
- 4.7.1

* Tue Aug 30 2011 Rex Dieter <rdieter@fedoraproject.org> 4.7.0-10
- first try

